@@ -9,12 +9,12 @@ our (@ISA, $VERSION, @EXPORT_OK, %EXPORT_TAGS);
 @ISA    = qw(IO::File Exporter);
 
 
-$VERSION = '2.102';
+$VERSION = '2.201';
 
 use constant G_EOF => 0 ;
 use constant G_ERR => -1 ;
 
-use IO::Compress::Base::Common 2.101 ;
+use IO::Compress::Base::Common 2.201 ;
 
 use IO::File ;
 use Symbol;
@@ -1006,6 +1006,11 @@ sub nextStream
 {
     my $self = shift ;
 
+    # An uncompressed file cannot have a next stream, so
+    # return immediately.
+    return 0
+        if *$self->{Plain} ;
+
     my $status = $self->gotoNextStream();
     $status == 1
         or return $status ;
@@ -1562,7 +1567,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
