@@ -48,7 +48,7 @@ sub full_name ($$) { # Returns the function name with potentially the
                      # prefixes 'S_' or 'Perl_'
     my ($func, $flags) = @_;
 
-    return "Perl_$func" if $flags =~ /p/;
+    return "Perl_$func" if $flags =~ /[ps]/;
     return "S_$func" if $flags =~ /[SIi]/;
     return $func;
 }
@@ -79,7 +79,7 @@ my ($embed, $core, $ext, $api) = setup_embed();
         }
 
         my ($flags,$retval,$plain_func,@args) = @$_;
-        if ($flags =~ / ( [^AabCDdEefFGhIiMmNnOoPpRrSsTUuWXx] ) /x) {
+        if ($flags =~ / ( [^AabCDdEefFGhIiMmNnOoPpRrSsTUuWXx;] ) /x) {
             die_at_end "flag $1 is not legal (for function $plain_func)";
         }
         my @nonnull;
@@ -107,11 +107,12 @@ my ($embed, $core, $ext, $api) = setup_embed();
                                                             && $flags !~ /m/;
 
         my $static_inline = 0;
-        if ($flags =~ /([SIi])/) {
+        if ($flags =~ /([SsIi])/) {
             my $type;
             if ($never_returns) {
                 $type = {
                     'S' => 'PERL_STATIC_NO_RET',
+                    's' => 'PERL_STATIC_NO_RET',
                     'i' => 'PERL_STATIC_INLINE_NO_RET',
                     'I' => 'PERL_STATIC_FORCE_INLINE_NO_RET'
                 }->{$1};
@@ -119,6 +120,7 @@ my ($embed, $core, $ext, $api) = setup_embed();
             else {
                 $type = {
                     'S' => 'STATIC',
+                    's' => 'STATIC',
                     'i' => 'PERL_STATIC_INLINE',
                     'I' => 'PERL_STATIC_FORCE_INLINE'
                 }->{$1};
@@ -136,10 +138,22 @@ my ($embed, $core, $ext, $api) = setup_embed();
             }
         }
 
+        $func = full_name($plain_func, $flags);
+
         die_at_end "For '$plain_func', M flag requires p flag"
                                             if $flags =~ /M/ && $flags !~ /p/;
-        die_at_end "For '$plain_func', C flag requires one of [pIimb] flags"
-                                            if $flags =~ /C/ && $flags !~ /[Iibmp]/;
+	my $C_required_flags = '[pIimbs]';
+        die_at_end
+	    "For '$plain_func', C flag requires one of $C_required_flags] flags"
+						if $flags =~ /C/
+						&& ($flags !~ /$C_required_flags/
+
+						   # Notwithstanding the
+						   # above, if the name won't
+						   # clash with a user name,
+						   # it's ok.
+						&& $plain_func !~ /^[Pp]erl/);
+
         die_at_end "For '$plain_func', X flag requires one of [Iip] flags"
                                             if $flags =~ /X/ && $flags !~ /[Iip]/;
         die_at_end "For '$plain_func', X and m flags are mutually exclusive"
@@ -153,7 +167,6 @@ my ($embed, $core, $ext, $api) = setup_embed();
         die_at_end "For '$plain_func', I and i flags are mutually exclusive"
                                             if $flags =~ /I/ && $flags =~ /i/;
 
-        $func = full_name($plain_func, $flags);
         $ret = "";
         $ret .= "$retval\t$func(";
         if ( $has_context ) {
@@ -165,9 +178,21 @@ my ($embed, $core, $ext, $api) = setup_embed();
             my $n;
             for my $arg ( @args ) {
                 ++$n;
-                if (   $args_assert_line
-		    && $arg =~ /\*/
-		    && $arg !~ /\b(NN|NULLOK)\b/ )
+		if ($arg =~ / ^ " (.+) " $ /x) {    # Handle literal string
+		    my $name = $1;
+
+		    # Make the string a legal C identifier; 'p' is arbitrary,
+		    # and is because C reserves leading underscores
+		    $name =~ s/^\W/p/a;
+		    $name =~ s/\W/_/ag;
+
+		    $arg = "const char * const $name";
+		    die_at_end 'm flag required for "literal" argument'
+							    unless $flags =~ /m/;
+		}
+		elsif (   $args_assert_line
+		       && $arg =~ /\*/
+		       && $arg !~ /\b(NN|NULLOK)\b/ )
 		{
                     warn "$func: $arg needs NN or NULLOK\n";
                     ++$unflagged_pointers;
@@ -216,6 +241,10 @@ my ($embed, $core, $ext, $api) = setup_embed();
         if ( $flags =~ /I/ ) {
             push @attrs, "__attribute__always_inline__";
         }
+        # roughly the inverse of the rules used in makedef.pl
+        if ( $flags !~ /[ACeIimSX]/ ) {
+            push @attrs, '__attribute__visibility__("hidden")'
+        }
         if( $flags =~ /f/ ) {
             my $prefix	= $has_context ? 'pTHX_' : '';
             my ($args, $pat);
